<?php

if (!defined('_PS_VERSION_'))
    exit;

class pushalertonsitemessaging extends Module {

    public function __construct() {
        $this->name = 'pushalertonsitemessaging';
        $this->tab = 'front_office_features';
        $this->version = '1.0';
        $this->author = 'PushAlert';
        $this->need_instance = 0;
        $this->ps_versions_compliancy = array('min' => '1.4', 'max' => '5.0');

        parent::__construct();
        $this->bootstrap = true;

        $this->displayName = $this->l('OnSite Messaging by PushAlert');
        $this->description = $this->l('Build your email marketing list with PushAlert OnSite Messaging. Keep users engaged with personalized on-site popups, automate cart abandonment recovery and browse abandonment with Exit Intent technology.');

        $this->confirmUninstall = $this->l('Are you sure you want to uninstall?');

        if (!Configuration::get('pa_onsite_presta_website_id')) {
            $this->warning = $this->l('Please Provide Website ID');
        }
    }

    public function install() {
        if (Shop::isFeatureActive()) {
            Shop::setContext(Shop::CONTEXT_ALL);
        }
        return parent::install();
    }

    public function uninstall() {
        return parent::uninstall() && Configuration::deleteByName('pa_onsite_presta_website_id');
    }

    public function getContent() {
        $output = null;

        if (Tools::isSubmit('submit' . $this->name)) {
            $website_id = strval(Tools::getValue('pa_onsite_presta_website_id'));
            if (empty($website_id) || !Validate::isGenericName($website_id)) {
                $output .= $this->displayError($this->l('Invalid Configuration Value'));
            } else {
                Configuration::updateValue('pa_onsite_presta_website_id', $website_id);
                $this->enable_applicable_hooks();
                $output .= $this->displayConfirmation($this->l('Settings updated'));
            }
        }
        return $output . $this->displayForm();
    }

    public function enable_applicable_hooks() {
        //$this->registerHook('displayBeforeBodyClosingTag');
		$this->registerHook('displayHeader');
		$this->registerHook('displayOrderConfirmation');
    }

    public function hookDisplayHeader($params) {
        if (_PS_VERSION_ < 1.7) {
            $this->context->controller->addJS('https://cdn.inwebr.com/inwebr_' . Configuration::get('pa_onsite_presta_website_id') . '.js');
        } else {
            $this->context->controller->registerJavascript(
                    'paonsitemessaging', 'https://cdn.inwebr.com/inwebr_' . Configuration::get('pa_onsite_presta_website_id') . '.js', array('server' => 'remote', 'position' => 'bottom', 'priority' => 150)
            );

        }
    }

    public function hookDisplayOrderConfirmation($params) {
        if (!($id_order = (int)Tools::getValue('id_order')) || !Validate::isUnsignedId($id_order)) {

        } else {
            $order = new Order($id_order);
            if (Validate::isLoadedObject($order) && $order->id_customer == $this->context->customer->id) {
                $cart = new Cart($order->id_cart);
                $total_amount_paid = $cart->getOrderTotal(true, Cart::BOTH);
                $id_order_state = (int)$order->getCurrentState();

                if($id_order_state!=_PS_OS_ERROR_) {
                    return "<script type=\"text/javascript\">(onsitemessagingbypa = window.onsitemessagingbypa || []).push(['conversion', 'presta_{$id_order}', '{$total_amount_paid}']);</script>";
                }
            } else {

            }
            unset($order);
        }
    }

    public function displayForm() {
        // Get default language
        $default_lang = (int) Configuration::get('PS_LANG_DEFAULT');

        // Init Fields form array
        $fields_form[0]['form'] = array(
            'legend' => array(
                'title' => $this->l('Settings'),
                'icon' => 'icon-cogs'
            ),
            'input' => array(
                array(
                    'type' => 'text',
                    'label' => $this->l('Website ID:'),
                    'name' => 'pa_onsite_presta_website_id',
                    'desc' => $this->l('Available in your PushAlert OnSite Messaging Dashboard, under Integrate > PrestaShop'),
                    'size' => 32,
                    'required' => true
                )
            ),
            'submit' => array(
                'title' => $this->l('Save')
            //'class' => 'btn btn-default pull-right'
            )
        );

        $helper = new HelperForm();
        // Module, token and currentIndex
        $helper->module = $this;
        $helper->name_controller = $this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->currentIndex = AdminController::$currentIndex . '&configure=' . $this->name;

        // Language
        $helper->default_form_language = $default_lang;
        $helper->allow_employee_form_lang = $default_lang;

        // Title and toolbar
        $helper->title = $this->displayName;
        $helper->show_toolbar = false;        // false -> remove toolbar
        $helper->submit_action = 'submit' . $this->name;
        // Load current value
        $helper->fields_value['pa_onsite_presta_website_id'] = Configuration::get('pa_onsite_presta_website_id');

        return $helper->generateForm($fields_form);
    }

}
